Skip to contents

Checks that an Atlas table has the columns needed by the public website and that dataset labels are not mixed accidentally.

Usage

validate_atlas_data(data, dataset = NULL)

Arguments

data

A data frame containing Atlas records.

dataset

Optional dataset label: "unambiguous" for dataset-I or "ambiguous" for dataset-II.

Value

A list with valid, errors, warnings, and summary.